@@ -1,6 +1,9 @@
-boot.overlap <- function (x, B = 1000, pairsOverlap = TRUE, ...)
+boot.overlap <- function (x, B = 1000, pairsOverlap = FALSE, ...)
 {
   
+  # control 
+  if (length(x) == 2 & pairsOverlap == TRUE) pairsOverlap <- FALSE
+  
   out <- overlap(x, ...)
   
   if (pairsOverlap) {
@@ -26,4 +29,4 @@ boot.overlap <- function (x, B = 1000, pairsOverlap = TRUE, ...)
   }
   OVboot <- data.frame(estOV = out, bias = bias, se = se)
   return(list(OVboot_stats = OVboot, OVboot_dist = outb))
-}
\ No newline at end of file
+}
